from distutils.core import setup

setup(
	name = "wc",
	version = "1.0.1",
	py_modules = ["wc"],
	author = "weviloju",
	author_email = "weviloju@hotmail.com",
	description = "Um simples modulo que troca o papel de parede do sistema operacional Linux, tudo utilizando Python",
)
